summaryrefslogtreecommitdiff
path: root/build/files.c
diff options
context:
space:
mode:
authorPanu Matilainen <pmatilai@redhat.com>2008-04-09 08:37:15 +0300
committerPanu Matilainen <pmatilai@redhat.com>2008-04-09 08:37:15 +0300
commite92d22e279fe01d84e339a45755eb9e8d989388d (patch)
tree43abae3631d55aafeaf43d4c04bef0c723f4b4fb /build/files.c
parente89e7ba72fa9e710cef780ed5931ed2c2d0603a8 (diff)
downloadlibrpm-tizen-e92d22e279fe01d84e339a45755eb9e8d989388d.tar.gz
librpm-tizen-e92d22e279fe01d84e339a45755eb9e8d989388d.tar.bz2
librpm-tizen-e92d22e279fe01d84e339a45755eb9e8d989388d.zip
URL -> path renames continued... (build internal)
Diffstat (limited to 'build/files.c')
-rw-r--r--build/files.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/build/files.c b/build/files.c
index 4a5c8d1e8..00b99be78 100644
--- a/build/files.c
+++ b/build/files.c
@@ -1358,7 +1358,7 @@ static FileListRec freeFileList(FileListRec fileList,
}
/* forward ref */
-static rpmRC recurseDir(FileList fl, const char * diskURL);
+static rpmRC recurseDir(FileList fl, const char * diskPath);
/**
* Add a file to the package manifest.
@@ -1553,10 +1553,10 @@ static rpmRC addFile(FileList fl, const char * diskURL,
/**
* Add directory (and all of its files) to the package manifest.
* @param fl package file tree walk data
* @param diskURL path to file
* @return RPMRC_OK on success
*/
-static rpmRC recurseDir(FileList fl, const char * diskURL)
+static rpmRC recurseDir(FileList fl, const char * diskPath)
{
char * ftsSet[2];
FTS * ftsp;
@@ -1567,7 +1567,7 @@ static rpmRC recurseDir(FileList fl, const char * diskURL)
fl->inFtw = 1; /* Flag to indicate file has buildRoot prefixed */
fl->isDir = 1; /* Keep it from following myftw() again */
- ftsSet[0] = (char *) diskURL;
+ ftsSet[0] = (char *) diskPath;
ftsSet[1] = NULL;
ftsp = Fts_open(ftsSet, myFtsOpts, NULL);
while ((fts = Fts_read(ftsp)) != NULL) {
@@ -1616,7 +1616,7 @@ static rpmRC recurseDir(FileList fl, const char * diskURL)
static rpmRC processMetadataFile(Package pkg, FileList fl,
const char * fileName, rpmTag tag)
{
- const char * buildURL = "%{_builddir}/%{?buildsubdir}/";
+ const char * buildDir = "%{_builddir}/%{?buildsubdir}/";
char * fn = NULL;
char * apkt = NULL;
uint8_t * pkt = NULL;
@@ -1629,7 +1629,7 @@ static rpmRC processMetadataFile(Package pkg, FileList fl,
fn = rpmGenPath(fl->buildRoot, NULL, fileName);
absolute = 1;
} else
- fn = rpmGenPath(buildURL, NULL, fileName);
+ fn = rpmGenPath(buildDir, NULL, fileName);
switch (tag) {
default:
@@ -1553,10 +1553,10 @@ static rpmRC addFile(FileList fl, const char * diskURL,
* Add directory (and all of its files) to the package manifest.
* @param fl package file tree walk data
- * @param diskURL path to file
+ * @param diskPath path to file
* @return RPMRC_OK on success
*/